/*
** Module   : CommonHandleChain.java
** Abstract : Defines common APIs used by handles which allow chaining.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CA  20130112 Created initial version.
** 002 VMN 20130217 Nameable and WriteablePrivateData interfaces extracted.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.ui.GenericWidget;

/**
 * Exposes the following methods or attributes, common for the window, widget,
 * frame and procedure handles:
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>NAME</td>
 *    <td>{@link #getName()}</td>
 * </tr>
 * <tr>
 *    <td>PREV-SIBLING</td>
 *    <td>{@link #getPrevSibling()}</td>
 * </tr>
 * <tr>
 *    <td>NEXT-SIBLING</td>
 *    <td>{@link #getNextSibling()}</td>
 * </tr>
 * <tr>
 *    <td>PRIVATE-DATA</td>
 *    <td>{@link #getPrivateData()}, {@link #setPrivateData(character)} and
 *        {@link #setPrivateData(String)}
 *    </td>
 * </tr>
 * </table>
 * This interface is used as a returned type by the 
 * {@link handle#unwrap(handle)} API, which, depending on the 
 * handle's state and type, it either returns an 
 * {@link ExternalProgramWrapper} instance (for procedure handles) or an 
 * {@link GenericWidget} instance (for widget, window and frame handles), or  
 * a dynamic proxy using {@link handle#invalidAttrAccessProxy}. 
 */
public interface CommonHandleChain
extends CommonHandle, Nameable, WriteablePrivateData
{
   /**
    * Get the <code>next-sibling</code> attribute of this handle.
    * 
    * @return   See above.
    */
   public handle getNextSibling();

   /**
    * Get the <code>prev-sibling</code> attribute of this handle.
    * 
    * @return   See above.
    */
   public handle getPrevSibling();

}
